@@ -11,7 +11,11 @@
 #include <QSharedPointer>
 #include <QVariantHash>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 namespace Grantlee
+#else
+namespace KTextTemplate
+#endif
 {
 class Engine;
 class FileSystemTemplateLoader;
@@ -38,12 +42,21 @@ public:
 private:
     Q_DISABLE_COPY(GrantleeTemplateManager)
     GrantleeTemplateManager();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QString errorTemplate(const QString &reason, const QString &origTemplateName, const Grantlee::Template &failedTemplate) const;
     Grantlee::Context createContext(const QVariantHash &hash = QVariantHash()) const;
-
+#else
+    QString errorTemplate(const QString &reason, const QString &origTemplateName, const KTextTemplate::Template &failedTemplate) const;
+    KTextTemplate::Context createContext(const QVariantHash &hash = QVariantHash()) const;
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Engine *const mEngine;
     QSharedPointer<Grantlee::FileSystemTemplateLoader> mLoader;
+#else
+    KTextTemplate::Engine *const mEngine;
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> mLoader;
+
+#endif
     QSharedPointer<GrantleeKi18nLocalizer> mLocalizer;
 
     static GrantleeTemplateManager *sInstance;
